@@ -1,11 +1,7 @@
 import abc
 import typing
-import warnings
-from openssh_key import utils
 
 from openssh_key.key_params import PrivateKeyParamsTypeVar, PublicKeyParamsTypeVar
-from openssh_key.pascal_style_byte_stream import PascalStyleByteStream
-
 
 
 SignatureContentsTypeVar = typing.TypeVar(
@@ -29,7 +25,7 @@ class SignatureContents(
         public_key_params: PublicKeyParamsTypeVar,
         challenge: bytes,
     ) -> bool:
-        raise NotImplementedError()
+        raise NotImplementedError('abstract method')
 
     @classmethod
     @abc.abstractmethod
@@ -38,4 +34,4 @@ class SignatureContents(
         private_key_params: PrivateKeyParamsTypeVar,
         challenge: bytes,
     ) -> SignatureContentsTypeVar:
-        raise NotImplementedError()
+        raise NotImplementedError('abstract method')
